@@ -9,16 +9,19 @@ from robot.libraries.BuiltIn import BuiltIn
 from SeleniumLibrary import SeleniumLibrary
 from SeleniumLibrary.utils.librarylistener import LibraryListener
 
-from .keywords import server
+from .keywords import server, webelements
 
 
 CLIENTS = [
     client for client in glob(join(dirname(__file__), "clients", "*")) if isdir(client)
 ]
 
-COMMON = list(glob(join(dirname(__file__), "common", "*.robot")))
+COMMON = list(glob(join(dirname(__file__), "common", "*.resource")))
 
-component_classes = [server.ServerKeywords]
+component_classes = [
+    webelements.WebElementKeywords,
+    server.ServerKeywords,
+]
 
 
 class JupyterLibrary(SeleniumLibrary):
@@ -69,7 +72,7 @@ class JupyterLibraryListener(LibraryListener):
             resources += ["JupyterLibrary/common/{}".format(basename(common))]
 
         for client in CLIENTS:
-            for path in glob(join(client, "*.robot")):
+            for path in glob(join(client, "*.resource")):
                 resources += [
                     "JupyterLibrary/clients/{}/{}".format(
                         basename(client), basename(path)
